@@ -6,7 +6,8 @@ import re
 import shlex
 import subprocess
 
-from clouds.aws.aws_utils import verify_aws_credentials
+from benedict import benedict
+from clouds.aws.aws_utils import set_and_verify_aws_credentials
 from simple_logger.logger import get_logger
 
 
@@ -14,6 +15,10 @@ LOGGER = get_logger(__name__)
 TIMEOUT_5MIN = 5 * 60
 
 
+class MissingAWSCredentials(Exception):
+    pass
+
+
 class CommandExecuteError(Exception):
     pass
 
@@ -24,7 +29,6 @@ class NotLoggedInError(Exception):
 
 @contextlib.contextmanager
 def rosa_login_logout(env, token, aws_region, allowed_commands=None):
-    verify_aws_credentials()
     _allowed_commands = allowed_commands or parse_help()
     build_execute_command(
         command=f"login {f'--env={env}' if env else ''} --token={token}",
@@ -83,38 +87,21 @@ def build_command(command, allowed_commands=None, aws_region=None):
     _user_command = shlex.split(command)
     command = ["rosa"]
     command.extend(_user_command)
-    json_output = {}
-    auto_answer_yes = {}
-    auto_update = {}
-    aws_region_flag = {}
-    for cmd in command[1:]:
-        if cmd.startswith("--"):
-            continue
+    commands_to_process = [_cmd for _cmd in _user_command if not _cmd.startswith("--")]
+    commands_dict = benedict(_allowed_commands, keypath_separator=" ")
+    _output = commands_dict[commands_to_process]
 
-        json_output = _allowed_commands.get(cmd, json_output.get(cmd, {}))
-        add_json_output = json_output.get("json_output") is True
-        if add_json_output:
-            command.append("-ojson")
+    if _output.get("json_output") is True:
+        command.append("-ojson")
 
-        auto_answer_yes = _allowed_commands.get(cmd, auto_answer_yes.get(cmd, {}))
-        add_auto_answer_yes = auto_answer_yes.get("auto_answer_yes") is True
-        if add_auto_answer_yes:
-            command.append("--yes")
+    if _output.get("auto_answer_yes") is True:
+        command.append("--yes")
 
-        auto_update = _allowed_commands.get(cmd, auto_update.get(cmd, {}))
-        add_auto_update = auto_update.get("auto_mode") is True
-        if add_auto_update:
-            command.append("--mode=auto")
+    if _output.get("auto_mode") is True:
+        command.append("--mode=auto")
 
-        aws_region_flag = _allowed_commands.get(cmd, aws_region_flag.get(cmd, {}))
-        add_aws_region_flag = json_output.get("region") is True
-        if add_aws_region_flag and aws_region:
-            command.append(f"--region={aws_region}")
-
-        if any(
-            [add_json_output, add_auto_answer_yes, add_auto_update, add_aws_region_flag]
-        ):
-            break
+    if _output.get("region") is True and aws_region:
+        command.append(f"--region={aws_region}")
 
     return command
 
@@ -307,6 +294,8 @@ def execute(
     _allowed_commands = allowed_commands or parse_help()
 
     if token or ocm_client:
+        set_and_verify_aws_credentials()
+
         if ocm_client:
             ocm_env = ocm_client.api_client.configuration.host
             token = ocm_client.api_client.token
@@ -332,3 +321,9 @@ def execute(
         return build_execute_command(
             command=command, allowed_commands=_allowed_commands, aws_region=aws_region
         )
+
+
+if __name__ == "__main__":
+    """
+    for local debugging.
+    """
